@@ -1,5 +1,6 @@
 package MooseX::ABC::Role::Object;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
 
 use Moose::Role;
 
@@ -9,7 +10,7 @@ MooseX::ABC::Role::Object - base object role for L<MooseX::ABC>
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -23,7 +24,7 @@ around new => sub {
     my $class = shift;
     my $meta = Class::MOP::class_of($class);
     $meta->throw_error("$class is abstract, it cannot be instantiated")
-        if $meta->has_required_methods;
+        if $meta->is_abstract;
     $class->$orig(@_);
 };
 
